==> libaqbanking_2.2.3.orig.tar.gz: aqbanking-2.2.3/src/plugins/backends/aqhbci/plugin/joblayer/job_p.h <==
/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: job_p.h 950 2006-02-22 19:39:02Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AH_JOB_P_H
#define AH_JOB_P_H

#include "job_l.h"
#include <gwenhywfar/stringlist.h>
#include <gwenhywfar/msgengine.h>



struct AH_JOB {
  GWEN_LIST_ELEMENT(AH_JOB);
  GWEN_INHERIT_ELEMENT(AH_JOB);

  char *name;
  char *accountId;
  char *description;

  char *expectedSigner;
  char *expectedCrypter;

  char *usedTan;

  AB_USER *user;

  unsigned int msgNum;
  char *dialogId;
  GWEN_TYPE_UINT32 firstSegment;
  GWEN_TYPE_UINT32 lastSegment;

  GWEN_STRINGLIST *signers;

  GWEN_XMLNODE *xmlNode;
  GWEN_XMLNODE *msgNode;
  GWEN_DB_NODE *jobParams;
  GWEN_DB_NODE *jobArguments;
  GWEN_DB_NODE *jobResponses;

  AH_JOB_STATUS status;
  GWEN_TYPE_UINT32 flags;
  int minSigs;
  int jobsPerMsg;

  GWEN_MSGENGINE *msgEngine;

  GWEN_TYPE_UINT32 usage;

  AH_JOB_PROCESS_FN processFn;
  AH_JOB_COMMIT_FN commitFn;

  AH_JOB_EXCHANGE_FN exchangeFn;

  AH_JOB_NEXTMSG_FN nextMsgFn;

  AH_RESULT_LIST *segResults;
  AH_RESULT_LIST *msgResults;

  GWEN_TYPE_UINT32 id;

  GWEN_STRINGLIST *log;
};


static void AH_Job_SampleResults(AH_JOB *j);
static AH_JOB *AH_Job__freeAll_cb(AH_JOB *j, void *userData);


#endif /* AH_JOB_P_H */

==> libaqbanking_3.7.2.orig.tar.gz: aqbanking-3.7.2/src/plugins/backends/aqhbci/plugin/joblayer/job_p.h <==
/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id$
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AH_JOB_P_H
#define AH_JOB_P_H

#include "job_l.h"
#include <gwenhywfar/stringlist.h>
#include <gwenhywfar/msgengine.h>



struct AH_JOB {
  GWEN_LIST_ELEMENT(AH_JOB);
  GWEN_INHERIT_ELEMENT(AH_JOB);

  char *name;
  char *accountId;
  char *description;

  int challengeClass;

  char *expectedSigner;
  char *expectedCrypter;

  char *usedTan;

  AB_USER *user;

  unsigned int msgNum;
  char *dialogId;
  uint32_t firstSegment;
  uint32_t lastSegment;

  GWEN_STRINGLIST *signers;

  GWEN_XMLNODE *xmlNode;
  GWEN_XMLNODE *msgNode;
  GWEN_DB_NODE *jobParams;
  GWEN_DB_NODE *jobArguments;
  GWEN_DB_NODE *jobResponses;

  AH_JOB_STATUS status;
  uint32_t flags;
  int minSigs;
  int secProfile;
  int jobsPerMsg;

  GWEN_MSGENGINE *msgEngine;

  uint32_t usage;

  AH_JOB_PROCESS_FN processFn;
  AH_JOB_COMMIT_FN commitFn;
  AH_JOB_PREPARE_FN prepareFn;

  AH_JOB_EXCHANGE_FN exchangeFn;

  AH_JOB_NEXTMSG_FN nextMsgFn;

  AH_RESULT_LIST *segResults;
  AH_RESULT_LIST *msgResults;

  uint32_t id;

  AB_MESSAGE_LIST *messages;

  GWEN_STRINGLIST *log;

  GWEN_STRINGLIST *challengeParams;
  AB_VALUE *challengeValue;
};


static void AH_Job_SampleResults(AH_JOB *j);
static AH_JOB *AH_Job__freeAll_cb(AH_JOB *j, void *userData);


#endif /* AH_JOB_P_H */
